@@ -37,6 +37,7 @@ K_PLUGIN_FACTORY_WITH_JSON(KCMPlymouthFactory, "kcm_plymouth.json", registerPlug
 
 KCMPlymouth::KCMPlymouth(QObject *parent, const QVariantList &args)
     : KQuickAddons::ConfigModule(parent, args)
+    , m_model(new QStandardItemModel(this))
 {
     qmlRegisterAnonymousType<QStandardItemModel>("KCMPlymouth", 1);
     qmlRegisterAnonymousType<KCMPlymouth>("KCMPlymouth", 1);
@@ -48,8 +49,6 @@ KCMPlymouth::KCMPlymouth(QObject *parent, const QVariantList &args)
     setAuthActionName(QStringLiteral("org.kde.kcontrol.kcmplymouth.save"));
     setNeedsAuthorization(true);
 
-    m_model = new QStandardItemModel(this);
-
     m_model->setItemRoleNames({{Qt::DisplayRole, QByteArrayLiteral("display")},
                                {DescriptionRole, QByteArrayLiteral("description")},
                                {PluginNameRole, QByteArrayLiteral("pluginName")},
@@ -108,7 +107,7 @@ void KCMPlymouth::reloadModel()
         m_model->appendRow(row);
     }
 
-    emit selectedPluginIndexChanged();
+    Q_EMIT selectedPluginIndexChanged();
 }
 
 void KCMPlymouth::onChangedEntriesChanged(const QQmlListReference &changedEntries)
@@ -144,8 +143,8 @@ void KCMPlymouth::setSelectedPlugin(const QString &plugin)
     }
 
     m_selectedPlugin = plugin;
-    emit selectedPluginChanged();
-    emit selectedPluginIndexChanged();
+    Q_EMIT selectedPluginChanged();
+    Q_EMIT selectedPluginIndexChanged();
 
     setNeedsSave(true);
 }
@@ -162,7 +161,7 @@ void KCMPlymouth::setBusy(const bool &busy)
     }
 
     m_busy = busy;
-    emit busyChanged();
+    Q_EMIT busyChanged();
 }
 
 int KCMPlymouth::selectedPluginIndex() const
@@ -201,7 +200,7 @@ void KCMPlymouth::save()
     bool rc = job->exec();
     if (!rc) {
         if (job->error() == KAuth::ActionReply::UserCancelledError) {
-            emit showErrorMessage(i18n("Unable to authenticate/execute the action: %1 (%2)", job->error(), job->errorString()));
+            Q_EMIT showErrorMessage(i18n("Unable to authenticate/execute the action: %1 (%2)", job->error(), job->errorString()));
         }
         load();
     }
@@ -221,11 +220,11 @@ void KCMPlymouth::uninstall(const QString &plugin)
     KAuth::ExecuteJob *job = action.execute();
     bool rc = job->exec();
     if (!rc) {
-        emit showErrorMessage(i18n("Unable to authenticate/execute the action: %1 (%2)", job->error(), job->errorString()));
+        Q_EMIT showErrorMessage(i18n("Unable to authenticate/execute the action: %1 (%2)", job->error(), job->errorString()));
     } else {
         KConfigGroup installedCg(KSharedConfig::openConfig(QStringLiteral("kplymouththemeinstallerrc")), "DownloadedThemes");
         installedCg.deleteEntry(plugin);
-        emit showSuccessMessage(i18n("Theme uninstalled successfully."));
+        Q_EMIT showSuccessMessage(i18n("Theme uninstalled successfully."));
         load();
     }
 }
